==> haskell-dns-2.0.1-15-armv7h.pkg.tar.xz: usr/share/haskell/haskell-dns/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 2.0.1
id: dns-2.0.1-a59fe8f11e1e2b7acb5e4d08faf1d289
key: dns_5psWVZW3fB85d8ydSTDmMa
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.DNS Network.DNS.Lookup Network.DNS.Resolver
    Network.DNS.Utils Network.DNS.Types Network.DNS.Encode
    Network.DNS.Decode
hidden-modules: Network.DNS.Internal Network.DNS.StateBinary
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/dns-2.0.1
hs-libraries: HSdns-2.0.1-5psWVZW3fB85d8ydSTDmMa
depends:
    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dns-2.0.1-16-armv7h.pkg.tar.xz: usr/share/haskell/haskell-dns/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 2.0.1
id: dns-2.0.1-3bc6bd18964f4fcaee15d296f6088006
key: dns_4EhFUrGxao38gqu5bEE97a
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.DNS Network.DNS.Lookup Network.DNS.Resolver
    Network.DNS.Utils Network.DNS.Types Network.DNS.Encode
    Network.DNS.Decode
hidden-modules: Network.DNS.Internal Network.DNS.StateBinary
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/dns-2.0.1
hs-libraries: HSdns-2.0.1-4EhFUrGxao38gqu5bEE97a
depends:
    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
